window.Gleam.initSearch([{"doc":"gleam_fetch","title":"gleam_fetch","content":"# Fetch\n\n&lt;a href=&quot;https://github.com/gleam-lang/fetch/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/gleam-lang/fetch&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt;\n&lt;a href=&quot;https://discord.gg/Fm8Pwmy&quot;&gt;&lt;img src=&quot;https://img.shields.io/discord/768594524158427167?color=blue&quot; alt=&quot;Discord chat&quot;&gt;&lt;/a&gt;\n![test](https://github.com/gleam-lang/fetch/workflows/test/badge.svg?branch=main)\n\nBindings to JavaScript&#39;s built in HTTP client, `fetch`.\n\n```gleam\nimport gleam/fetch\nimport gleam/http.{Get}\nimport gleam/http/request\nimport gleam/http/response.{Response}\nimport gleam/javascript/promise.{try_await}\n\npub fn main() {\n  // Prepare a HTTP request record\n  let req = request.new()\n    |&gt; request.set_method(Get)\n    |&gt; request.set_host(&quot;test-api.service.hmrc.gov.uk&quot;)\n    |&gt; request.set_path(&quot;/hello/world&quot;)\n    |&gt; request.prepend_header(&quot;accept&quot;, &quot;application/vnd.hmrc.1.0+json&quot;)\n\n  // Send the HTTP request to the server\n  use resp &lt;- try_await(fetch.send(req))\n  use resp &lt;- try_await(fetch.read_text_body(resp))\n\n  // We get a response record back\n  assert Response(status: 200, ..) = resp\n\n  assert Ok(&quot;application/json&quot;) = response.get_header(resp, &quot;content-type&quot;)\n  assert &quot;{\\&quot;message\\&quot;:\\&quot;Hello World\\&quot;}&quot; = resp.body\n\n  promise.resolve(Ok(Nil))\n}\n```\n","url":"index.html"},{"doc":"gleam/fetch","title":"FetchBody","content":"pub type FetchBody\n\n\nSynonyms:\ngleam/fetch.FetchBody\ngleam/fetch FetchBody","url":"gleam/fetch.html#FetchBody"},{"doc":"gleam/fetch","title":"FetchError","content":"pub type FetchError {\n  NetworkError(String)\n  UnableToReadBody\n  InvalidJsonBody\n}\n\nNetworkError(String)\n\n\nUnableToReadBody\n\n\nInvalidJsonBody\n\n\nSynonyms:\ngleam/fetch.FetchError\ngleam/fetch FetchError","url":"gleam/fetch.html#FetchError"},{"doc":"gleam/fetch","title":"FetchRequest","content":"pub type FetchRequest\n\n\nSynonyms:\ngleam/fetch.FetchRequest\ngleam/fetch FetchRequest","url":"gleam/fetch.html#FetchRequest"},{"doc":"gleam/fetch","title":"FetchResponse","content":"pub type FetchResponse\n\n\nSynonyms:\ngleam/fetch.FetchResponse\ngleam/fetch FetchResponse","url":"gleam/fetch.html#FetchResponse"},{"doc":"gleam/fetch","title":"from_fetch_response","content":"pub fn from_fetch_response(a: FetchResponse) -&gt; Response(\n  FetchBody,\n)\n\nSynonyms:\ngleam/fetch.from_fetch_response\ngleam/fetch from_fetch_response","url":"gleam/fetch.html#from_fetch_response"},{"doc":"gleam/fetch","title":"raw_send","content":"pub fn raw_send(a: FetchRequest) -&gt; Promise(\n  Result(FetchResponse, FetchError),\n)\n\nSynonyms:\ngleam/fetch.raw_send\ngleam/fetch raw_send","url":"gleam/fetch.html#raw_send"},{"doc":"gleam/fetch","title":"read_json_body","content":"pub fn read_json_body(a: Response(FetchBody)) -&gt; Promise(\n  Result(Response(Dynamic), FetchError),\n)\n\nSynonyms:\ngleam/fetch.read_json_body\ngleam/fetch read_json_body","url":"gleam/fetch.html#read_json_body"},{"doc":"gleam/fetch","title":"read_text_body","content":"pub fn read_text_body(a: Response(FetchBody)) -&gt; Promise(\n  Result(Response(String), FetchError),\n)\n\nSynonyms:\ngleam/fetch.read_text_body\ngleam/fetch read_text_body","url":"gleam/fetch.html#read_text_body"},{"doc":"gleam/fetch","title":"send","content":"pub fn send(request: Request(String)) -&gt; Promise(\n  Result(Response(FetchBody), FetchError),\n)\n\nSynonyms:\ngleam/fetch.send\ngleam/fetch send","url":"gleam/fetch.html#send"},{"doc":"gleam/fetch","title":"to_fetch_request","content":"pub fn to_fetch_request(a: Request(String)) -&gt; FetchRequest\n\nSynonyms:\ngleam/fetch.to_fetch_request\ngleam/fetch to_fetch_request","url":"gleam/fetch.html#to_fetch_request"},{"doc":"gleam/fetch","title":"gleam/fetch","content":"","url":"gleam/fetch.html"}]);